package com.ynet.life.action;

import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEException;
import com.ynet.gene.data.DataElement;
import com.ynet.gene.data.IndexedCollection;
import com.ynet.gene.data.InvalidArgumentException;
import com.ynet.gene.data.KeyedCollection;
import com.ynet.gene.data.ObjectNotFoundException;
import com.ynet.life.base.LifeAction;
import com.ynet.life.base.LifeStandard;
import com.ynet.life.base.TEntity;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import java.util.StringTokenizer;
import javax.net.ssl.SSLHandshakeException;
import org.apache.http.HttpEntity;
import org.apache.http.HttpEntityEnclosingRequest;
import org.apache.http.HttpRequest;
import org.apache.http.HttpVersion;
import org.apache.http.NoHttpResponseException;
import org.apache.http.client.HttpClient;
import org.apache.http.client.HttpRequestRetryHandler;
import org.apache.http.client.entity.UrlEncodedFormEntity;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.impl.client.DefaultHttpClient;
import org.apache.http.message.BasicNameValuePair;
import org.apache.http.params.HttpConnectionParams;
import org.apache.http.params.HttpParams;
import org.apache.http.protocol.HttpContext;
import org.apache.http.util.EntityUtils;

/* loaded from: com_ynet_life_action.jar:com/ynet/life/action/ExeAutoTask.class */
public class ExeAutoTask extends LifeAction {
    private static final String PARAMS_SEPERATOR = "&";
    private String paramsFiled;
    private Map<String, String> params = new HashMap();
    private String bsnCode;
    private String IcollFiled;
    private static HttpRequestRetryHandler requestRetryHandler = new HttpRequestRetryHandler() { // from class: com.ynet.life.action.ExeAutoTask.1
        @Override // org.apache.http.client.HttpRequestRetryHandler
        public boolean retryRequest(IOException exception, int executionCount, HttpContext context) {
            if (executionCount >= 0) {
                return false;
            }
            if (exception instanceof NoHttpResponseException) {
                return true;
            }
            if (!(exception instanceof SSLHandshakeException) && !(((HttpRequest) context.getAttribute("http.request")) instanceof HttpEntityEnclosingRequest)) {
                return true;
            }
            return false;
        }
    };

    public String execute(Context context) throws GENEException {
        if ("".equals(this.bsnCode) || this.bsnCode == null) {
            throw new TranFailException("LifeAction", "获取交易参数异常", false);
        }
        this.params.put("bsn", this.bsnCode);
        IndexedCollection icoll = (IndexedCollection) context.getDataElement(this.IcollFiled);
        setParams(context);
        setIcollparam(icoll, this.IcollFiled);
        httpPost(LifeStandard.getSelfDefineSettingsValue(TEntity.autoTaskServerAddress), this.params, "utf-8");
        return null;
    }

    public static void httpGet(String url, Map<String, String> params, String reqCharSet) throws TranFailException {
        try {
            HttpClient httpClient = getDefaultHttpClient(reqCharSet);
            HttpGet httpGet = new HttpGet(url);
            String reMsg = EntityUtils.toString(httpClient.execute(httpGet).getEntity(), "utf-8");
            if (!"000000".equals(reMsg)) {
                throw new TranFailException("EBLN5009");
            }
        } catch (Exception unused) {
            throw new TranFailException("EBLN5009");
        }
    }

    public static void httpPost(String url, Map<String, String> map, String reqCharSet) throws TranFailException {
        try {
            HttpClient httpClient = getDefaultHttpClient(reqCharSet);
            ArrayList<BasicNameValuePair> list = new ArrayList<>();
            HttpPost httpPost = new HttpPost(url);
            for (String keyString : map.keySet()) {
                list.add(new BasicNameValuePair(keyString, map.get(keyString)));
            }
            HttpEntity httpEntity = new UrlEncodedFormEntity(list, reqCharSet);
            httpPost.setEntity(httpEntity);
            String reMsg = EntityUtils.toString(httpClient.execute(httpPost).getEntity(), "utf-8");
            if (!"000000".equals(reMsg)) {
                throw new TranFailException("EBLN5009");
            }
        } catch (Exception unused) {
            throw new TranFailException("EBLN5009");
        }
    }

    private static DefaultHttpClient getDefaultHttpClient(String charset) {
        DefaultHttpClient httpclient = new DefaultHttpClient();
        HttpParams params = httpclient.getParams();
        params.setParameter("http.protocol.version", HttpVersion.HTTP_1_1);
        params.setParameter("http.useragent", "Mozilla/4.0 (compatible; MSIE 7.0; MSIE 8.0;MSIE 9.0;Windows NT 5.1)");
        params.setParameter("http.protocol.expect-continue", Boolean.FALSE);
        params.setParameter("http.protocol.content-charset", charset == null ? "utf-8" : charset);
        httpclient.setHttpRequestRetryHandler(requestRetryHandler);
        HttpConnectionParams.setConnectionTimeout(params, 10000);
        HttpConnectionParams.setSoTimeout(params, 20000);
        return httpclient;
    }

    private void setParams(Context context) throws GENEException {
        if ("".equals(this.paramsFiled) || this.paramsFiled == null) {
            return;
        }
        try {
            String paramsCopy = (String) context.getDataValue(this.paramsFiled);
            if (paramsCopy != null && !"".equals(paramsCopy)) {
                new StringBuffer();
                StringTokenizer toke = new StringTokenizer(paramsCopy, PARAMS_SEPERATOR);
                while (toke.hasMoreElements()) {
                    String fieldName = ((String) toke.nextElement()).trim();
                    try {
                        String fieldValue = (String) context.getDataValue(fieldName);
                        if (fieldValue == null) {
                            fieldValue = "";
                        }
                        this.params.put(fieldName, fieldValue);
                    } catch (GENEException ex) {
                        Trace.logError("LifeAction", "获取交易参数异常", ex);
                        throw ex;
                    }
                }
            }
        } catch (GENEException ex2) {
            Trace.logError("LifeAction", "获取交易参数异常", ex2);
            throw ex2;
        }
    }

    public void setIcollparam(IndexedCollection icoll, String icollName) throws InvalidArgumentException, ObjectNotFoundException {
        new StringBuffer();
        if (icoll == null || icoll.size() == 0) {
            return;
        }
        KeyedCollection kcoll = icoll.getElementAt(0);
        Map<String, String> map = new HashMap<>();
        kcoll.size();
        for (int j = 0; j < kcoll.size(); j++) {
            DataElement element = kcoll.getDataElement(j);
            map.put(String.valueOf(icollName) + "." + element.getName(), (String) kcoll.getDataValue(element.getName()));
        }
        for (int i = 1; i < icoll.size(); i++) {
            KeyedCollection kcoll2 = icoll.getElementAt(i);
            Iterator iterator = kcoll2.keySet().iterator();
            for (int f = 0; f < kcoll2.size(); f++) {
                String key = (String) iterator.next();
                String IcollKey = String.valueOf(icollName) + "." + key;
                if (map.get(IcollKey) != null && !"".equals(map.get(IcollKey))) {
                    String dataValue = String.valueOf(map.get(IcollKey)) + "," + ((String) kcoll2.getDataValue(key));
                    map.put(IcollKey, dataValue);
                } else {
                    map.put(IcollKey, (String) kcoll2.getDataValue(key));
                }
            }
        }
        for (String key2 : map.keySet()) {
            this.params.put(key2, map.get(key2));
        }
    }

    public String getParamsFiled() {
        return this.paramsFiled;
    }

    public void setParamsFiled(String paramsFiled) {
        this.paramsFiled = paramsFiled;
    }

    public String getBsnCode() {
        return this.bsnCode;
    }

    public void setBsnCode(String bsnCode) {
        this.bsnCode = bsnCode;
    }

    public String getIcollFiled() {
        return this.IcollFiled;
    }

    public void setIcollFiled(String icollFiled) {
        this.IcollFiled = icollFiled;
    }

    public static void main(String[] args) {
        Map<String, String> params = new HashMap<>();
        TranFailException put = params.put("bsn", "per0001");
        try {
            httpPost("http://127.0.0.1:8080/autoTask/test", params, "utf-8");
            put = System.out;
            put.println("======================");
        } catch (TranFailException e) {
            put.printStackTrace();
        }
    }
}
